@@ -5,9 +5,10 @@ from PIL import Image
 from six.moves import zip
 
 from ._encode import ffi as _ffi, lib as _lib
+from ._version import version as __version__
 
 
-__all__ = 'encode',
+__all__ = 'encode', '__version__',
 
 
 def encode(image_file, x_components, y_components):
@@ -32,4 +33,4 @@ def encode(image_file, x_components, y_components):
     if result == _ffi.NULL:
         raise ValueError('Invalid x_components or y_components')
 
-    return _ffi.string(result)
+    return _ffi.string(result).decode()
